@@ -176,17 +176,10 @@ unrealize (GtkWidget *widget)
 {
 	NautilusDesktopWindow *window;
 	NautilusDesktopWindowDetails *details;
-	GdkWindow *root_window;
 
 	window = NAUTILUS_DESKTOP_WINDOW (widget);
 	details = window->details;
 
-	root_window = gdk_screen_get_root_window (
-				gtk_window_get_screen (GTK_WINDOW (window)));
-
-	gdk_property_delete (root_window,
-			     gdk_atom_intern ("NAUTILUS_DESKTOP_WINDOW_ID", TRUE));
-
 	if (details->size_changed_id != 0) {
 		g_signal_handler_disconnect (gtk_window_get_screen (GTK_WINDOW (window)),
 					     details->size_changed_id);
@@ -209,31 +202,12 @@ set_wmspec_desktop_hint (GdkWindow *window)
 			     GDK_PROP_MODE_REPLACE, (guchar *) &atom, 1);
 }
 
-static void
-set_desktop_window_id (NautilusDesktopWindow *window,
-		       GdkWindow             *gdkwindow)
-{
-	/* Tuck the desktop windows xid in the root to indicate we own the desktop.
-	 */
-	Window window_xid;
-	GdkWindow *root_window;
-
-	root_window = gdk_screen_get_root_window (
-				gtk_window_get_screen (GTK_WINDOW (window)));
-
-	window_xid = GDK_WINDOW_XID (gdkwindow);
-
-	gdk_property_change (root_window,
-			     gdk_atom_intern ("NAUTILUS_DESKTOP_WINDOW_ID", FALSE),
-			     gdk_x11_xatom_to_atom (XA_WINDOW), 32,
-			     GDK_PROP_MODE_REPLACE, (guchar *) &window_xid, 1);
-}
-
 static void
 realize (GtkWidget *widget)
 {
 	NautilusDesktopWindow *window;
 	NautilusDesktopWindowDetails *details;
+	GdkVisual *visual;
 
 	window = NAUTILUS_DESKTOP_WINDOW (widget);
 	details = window->details;
@@ -242,14 +216,17 @@ realize (GtkWidget *widget)
 	gtk_widget_set_events (widget, gtk_widget_get_events (widget) 
 			      | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 			      
+	visual = gdk_screen_get_rgba_visual (gtk_widget_get_screen (widget));
+	if (visual) {
+		gtk_widget_set_visual (widget, visual);
+	}
+
 	/* Do the work of realizing. */
 	GTK_WIDGET_CLASS (nautilus_desktop_window_parent_class)->realize (widget);
 
 	/* This is the new way to set up the desktop window */
 	set_wmspec_desktop_hint (gtk_widget_get_window (widget));
 
-	set_desktop_window_id (window, gtk_widget_get_window (widget));
-
 	details->size_changed_id =
 		g_signal_connect (gtk_window_get_screen (GTK_WINDOW (window)), "size-changed",
 				  G_CALLBACK (nautilus_desktop_window_screen_size_changed), window);
